# flask-create-app

Script para criar a base de um projeto flask para usar como extensão ou como aplicação final

## Instalação

Instale usando o pipx (recomendado)

`pipx install flask-create-app`

Mas você pode também instalar com pip:

`pip install flask-create-app`

## Como Usar

Crie a pasta para seu projeto e dentro dela rode `flask-create-app .`
